==> haskell-authenticate-oauth-1.6.0.1-283-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-authenticate-oauth.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 authenticate-oauth
version:              1.6.0.1
visibility:           public
id:                   authenticate-oauth-1.6.0.1-IALTNpUkfJp4XYS9HLYYiH
key:                  authenticate-oauth-1.6.0.1-IALTNpUkfJp4XYS9HLYYiH
license:              BSD-3-Clause
maintainer:           Hiromi Ishii, Artem Chirkin
author:               Hiromi Ishii
stability:            Stable
homepage:             http://github.com/yesodweb/authenticate
synopsis:
    Library to authenticate with OAuth for Haskell web applications.

description:
    API docs and the README are available at <http://www.stackage.org/package/authenticate-oauth>.

category:             Web
abi:                  ce0643d1ecd2701c8fb1d231f41d6eb3
exposed:              True
exposed-modules:      Web.Authenticate.OAuth Web.Authenticate.OAuth.IO
import-dirs:          /usr/lib/ghc-8.10.5/site-local/authenticate-oauth-1.6.0.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/authenticate-oauth-1.6.0.1
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.5/authenticate-oauth-1.6.0.1

hs-libraries:         HSauthenticate-oauth-1.6.0.1-IALTNpUkfJp4XYS9HLYYiH
depends:
    RSA-2.4.1-C8p4SEuYZLKDnZPSZwbFDe SHA-1.6.4.4-AdaX3b9QKHpD4bkKnWphTy
    base-4.14.2.0 base64-bytestring-1.2.0.1-6PvrigrzgN5CFxMJsxx0QP
    blaze-builder-0.4.2.1-CvyaA91rGJh3LGq34EOJVB bytestring-0.10.12.0
    crypto-pubkey-types-0.4.3-5lZS6p7yh6bJ01NaZLle2g
    data-default-0.7.1.1-1PvF2urvLxF7Pa94frLNmw
    http-client-0.7.8-5DGKG4V4shl2JbX54gJKhJ
    http-types-0.12.3-19oZT8Fua6FHdxhPU1oghZ
    random-1.2.0-FYrBsLYhb8t9oQNjLyUagP time-1.9.3 transformers-0.5.6.2
    transformers-compat-0.6.6-8xD7tdhdla21VYsnm1hEvk

haddock-interfaces:
    /usr/share/doc/haskell-authenticate-oauth/html/authenticate-oauth.haddock

haddock-html:         /usr/share/doc/haskell-authenticate-oauth/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-authenticate-oauth-1.6.0.1-284-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-authenticate-oauth.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 authenticate-oauth
version:              1.6.0.1
visibility:           public
id:                   authenticate-oauth-1.6.0.1-DnvY213cMnu4wtxh6qJIsb
key:                  authenticate-oauth-1.6.0.1-DnvY213cMnu4wtxh6qJIsb
license:              BSD-3-Clause
maintainer:           Hiromi Ishii, Artem Chirkin
author:               Hiromi Ishii
stability:            Stable
homepage:             http://github.com/yesodweb/authenticate
synopsis:
    Library to authenticate with OAuth for Haskell web applications.

description:
    API docs and the README are available at <http://www.stackage.org/package/authenticate-oauth>.

category:             Web
abi:                  dbf54fa315a8c5da160e83765bc512cf
exposed:              True
exposed-modules:      Web.Authenticate.OAuth Web.Authenticate.OAuth.IO
import-dirs:          /usr/lib/ghc-8.10.5/site-local/authenticate-oauth-1.6.0.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/authenticate-oauth-1.6.0.1
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.5/authenticate-oauth-1.6.0.1

hs-libraries:         HSauthenticate-oauth-1.6.0.1-DnvY213cMnu4wtxh6qJIsb
depends:
    RSA-2.4.1-C8p4SEuYZLKDnZPSZwbFDe SHA-1.6.4.4-AdaX3b9QKHpD4bkKnWphTy
    base-4.14.2.0 base64-bytestring-1.2.0.1-6PvrigrzgN5CFxMJsxx0QP
    blaze-builder-0.4.2.1-CvyaA91rGJh3LGq34EOJVB bytestring-0.10.12.0
    crypto-pubkey-types-0.4.3-5lZS6p7yh6bJ01NaZLle2g
    data-default-0.7.1.1-1PvF2urvLxF7Pa94frLNmw
    http-client-0.7.8-Ip7bMuXtTRTGAUw6Da3sWW
    http-types-0.12.3-19oZT8Fua6FHdxhPU1oghZ
    random-1.2.0-FYrBsLYhb8t9oQNjLyUagP time-1.9.3 transformers-0.5.6.2
    transformers-compat-0.6.6-8xD7tdhdla21VYsnm1hEvk

haddock-interfaces:
    /usr/share/doc/haskell-authenticate-oauth/html/authenticate-oauth.haddock

haddock-html:         /usr/share/doc/haskell-authenticate-oauth/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
